rnalysis.filtering.CountFilter.majority\_vote\_intersection
===========================================================

.. currentmodule:: rnalysis.filtering

.. automethod:: CountFilter.majority_vote_intersection